@@ -87,7 +87,7 @@ class TokenAuthorization(Authorization):
             g._flask_json_resource_token = \
                 self.token_class({'access_token': self.token_string}).load()
             return g._flask_json_resource_token
-        except ResourceNotFound:
+        except (ResourceNotFound, UnAuthorized):
             raise UnAuthorized('Invalid Access token')
 
     def check_authorization(self):
